unit iadoconst;

interface

uses
    SysUtils, Classes;

const
    //  DataTypeEnum
    adEmpty            =     0; //  Specifies no value (DBTYPE_EMPTY).
    adSmallInt         =     2; //  Indicates a two-byte signed integer (DBTYPE_I2).
    adInteger          =     3; //  Indicates a four-byte signed integer (DBTYPE_I4).
    adSingle           =     4; //  Indicates a single-precision floating-point value (DBTYPE_R4).
    adDouble           =     5; //  Indicates a double-precision floating-point value (DBTYPE_R8).
    adCurrency         =     6; //  Indicates a currency value (DBTYPE_CY). Currency is a fixed-point number with four digits to the right of the decimal point. It is stored in an eight-byte signed integer scaled by 10,000.
    adDate             =     7; //  Indicates a date value (DBTYPE_DATE). A date is stored as a double, the whole part of which is the number of days since December 30, 1899, and the fractional part of which is the fraction of a day.
    adBSTR             =     8; //  Indicates a null-terminated character string (Unicode) (DBTYPE_BSTR).
    adIDispatch        =     9; //  Indicates a pointer to an IDispatch interface on a COM object (DBTYPE_IDISPATCH).
                                //  This data type is currently not supported by ADO. Usage may cause unpredictable results.
    adError            =    10; //  Indicates a 32-bit error code (DBTYPE_ERROR).
    adBoolean          =    11; //  Indicates a boolean value (DBTYPE_BOOL).
    adVariant          =    12; //  Indicates an Automation Variant (DBTYPE_VARIANT).
                                //  This data type is currently not supported by ADO. Usage may cause unpredictable results.
    adIUnknown         =    13; //  Indicates a pointer to an IUnknown interface on a COM object (DBTYPE_IUNKNOWN).
                                //  This data type is currently not supported by ADO. Usage may cause unpredictable results.
    adDecimal          =    14; //  Indicates an exact numeric value with a fixed precision and scale (DBTYPE_DECIMAL).
    adTinyInt          =    16; //  Indicates a one-byte signed integer (DBTYPE_I1).
    adUnsignedTinyInt  =    17; //  Indicates a one-byte unsigned integer (DBTYPE_UI1).
    adUnsignedSmallInt =    18; //  Indicates a two-byte unsigned integer (DBTYPE_UI2).
    adUnsignedInt      =    19; //  Indicates a four-byte unsigned integer (DBTYPE_UI4).
    adBigInt           =    20; //  Indicates an eight-byte signed integer (DBTYPE_I8).
    adUnsignedBigInt   =    21; //  Indicates an eight-byte unsigned integer (DBTYPE_UI8).
    adFileTime         =    64; //  Indicates a 64-bit value representing the number of 100-nanosecond intervals since January 1, 1601 (DBTYPE_FILETIME).
    adGUID             =    72; //  Indicates a globally unique identifier (GUID) (DBTYPE_GUID).
    adBinary           =   128; //  Indicates a binary value (DBTYPE_BYTES).
    adChar             =   129; //  Indicates a string value (DBTYPE_STR).
    adWChar            =   130; //  Indicates a null-terminated Unicode character string (DBTYPE_WSTR).
    adNumeric          =   131; //  Indicates an exact numeric value with a fixed precision and scale (DBTYPE_NUMERIC).
    adUserDefined      =   132; //  Indicates a user-defined variable (DBTYPE_UDT).
    adDBDate           =   133; //  Indicates a date value (yyyymmdd) (DBTYPE_DBDATE).
    adDBTime           =   134; //  Indicates a time value (hhmmss) (DBTYPE_DBTIME).
    adDBTimeStamp      =   135; //  Indicates a date/time stamp (yyyymmddhhmmss plus a fraction in billionths) (DBTYPE_DBTIMESTAMP).
    adChapter          =   136; //  Indicates a four-byte chapter value that identifies rows in a child rowset (DBTYPE_HCHAPTER).
    adPropVariant      =   138; //  Indicates an Automation PROPVARIANT (DBTYPE_PROP_VARIANT).
    adVarNumeric       =   139; //  Indicates a numeric value (Parameter object only).
    adVarChar          =   200; //  Indicates a string value.
    adLongVarChar      =   201; //  Indicates a long string value.
    adVarWChar         =   202; //  Indicates a null-terminated Unicode character string.
    adLongVarWChar     =   203; //  Indicates a long null-terminated Unicode string value.
    adVarBinary        =   204; //  Indicates a binary value (Parameter object only).
    adLongVarBinary    =   205; //  Indicates a long binary value.
    AdArray            = $2000; //  A flag value, always combined with another data type constant, that indicates an array of that other data type.

    //  KeyTypeEnum
    adKeyPrimary    = 1;
    adKeyForeign    = 2;
    adKeyUnique     = 3;
    S_KeyTypeEnum: array[adKeyPrimary..adKeyUnique] of string
                    = ('PK', 'FK', 'UQ');

    //  ColumnAttributesEnum
    adColFixed      = 1;
    adColNullable   = 2;
    S_ColumnAttributesEnum: array[adColFixed..adColNullable] of string
                    = ('Œ蒷', 'NULL');
    //  RuleEnum
    adRINone        = 0;
    adRICascade     = 1;
    adRISetNull     = 2;
    adRISetDefault  = 3;
    S_RuleEnum: array[adRINone..adRISetDefault] of string
                    = ('@', 'Ag', 'NULLݒ', 'lݒ');

    //  AllowNullsEnum
    adIndexNullsAllow       = 0;
    adIndexNullsDisallow    = 1;
    adIndexNullsIgnore      = 2;
    adIndexNullsIgnoreAny   = 4;
    S_AllowNullsEnum: array[adIndexNullsAllow..adIndexNullsIgnoreAny] of string
                    = ('NULL', 'NULLs', 'NULL', '', 'NULL');

    //  SortOrderEnum
    adSortAscending     = 1;
    adSortDescending    = 2;
    S_SortOrderEnum: array[adSortAscending..adSortDescending] of string
                    = ('', '~');

function DataTypeEnum2Str(const AdoType: integer): string;
function ColumnAttributesEnum2Str(const AdoType: integer): string;
function AllowNullsEnum2Str(const AdoType: integer): string;
function TransPropName(const PropName: string): string;

implementation

//-----------------------------------------------------------------------------
//  tO܂ł邩?
function FlagInclude(const Flags, Flag: integer): Boolean;
begin
    Result := ((Flags and Flag) = Flag);
end;

//-----------------------------------------------------------------------------
//  f[^^
function DataTypeEnum2Str(const AdoType: integer): string;
var
    aType: integer;
    Temp: string;
begin
    //  ztO܂ނǂ
    aType := AdoType;
    if (aType >= AdArray) then
    begin
        Dec(aType, AdArray);
        Temp := '[Array]';
    end
    else
    begin
        Temp := '';
    end;
    //  ^
    if (aType = adEmpty           ) then Result := 'Empty'            else
    if (aType = adSmallInt        ) then Result := 'SmallInt'         else
    if (aType = adInteger         ) then Result := 'Integer'          else
    if (aType = adSingle          ) then Result := 'Single'           else
    if (aType = adDouble          ) then Result := 'Double'           else
    if (aType = adCurrency        ) then Result := 'Currency'         else
    if (aType = adDate            ) then Result := 'Date'             else
    if (aType = adBSTR            ) then Result := 'BSTR'             else
    if (aType = adIDispatch       ) then Result := 'IDispatch'        else
    if (aType = adError           ) then Result := 'Error'            else
    if (aType = adBoolean         ) then Result := 'Boolean'          else
    if (aType = adVariant         ) then Result := 'Variant'          else
    if (aType = adIUnknown        ) then Result := 'IUnknown'         else
    if (aType = adDecimal         ) then Result := 'Decimal'          else
    if (aType = adTinyInt         ) then Result := 'TinyInt'          else
    if (aType = adUnsignedTinyInt ) then Result := 'UnsignedTinyInt'  else
    if (aType = adUnsignedSmallInt) then Result := 'UnsignedSmallInt' else
    if (aType = adUnsignedInt     ) then Result := 'UnsignedInt'      else
    if (aType = adBigInt          ) then Result := 'BigInt'           else
    if (aType = adUnsignedBigInt  ) then Result := 'UnsignedBigInt'   else
    if (aType = adFileTime        ) then Result := 'FileTime'         else
    if (aType = adGUID            ) then Result := 'GUID'             else
    if (aType = adBinary          ) then Result := 'Binary'           else
    if (aType = adChar            ) then Result := 'Char'             else
    if (aType = adWChar           ) then Result := 'WChar'            else
    if (aType = adNumeric         ) then Result := 'Numeric'          else
    if (aType = adUserDefined     ) then Result := 'UserDefined'      else
    if (aType = adDBDate          ) then Result := 'DBDate'           else
    if (aType = adDBTime          ) then Result := 'DBTime'           else
    if (aType = adDBTimeStamp     ) then Result := 'DBTimeStamp'      else
    if (aType = adChapter         ) then Result := 'Chapter'          else
    if (aType = adPropVariant     ) then Result := 'PropVariant'      else
    if (aType = adVarNumeric      ) then Result := 'VarNumeric'       else
    if (aType = adVarChar         ) then Result := 'VarChar'          else
    if (aType = adLongVarChar     ) then Result := 'LongVarChar'      else
    if (aType = adVarWChar        ) then Result := 'VarWChar'         else
    if (aType = adLongVarWChar    ) then Result := 'LongVarWChar'     else
    if (aType = adVarBinary       ) then Result := 'VarBinary'        else
    if (aType = adLongVarBinary   ) then Result := 'LongVarBinary'    else
    if (aType = adArray           ) then Result := 'Array'            else
    Result := '';

    Result := Result + Temp;
end;

//-----------------------------------------------------------------------------
//  tB[h̑
function ColumnAttributesEnum2Str(const AdoType: integer): string;
begin
    //  Œ蒷ǂ
    if (AdoType = adColFixed) then
        Result := S_ColumnAttributesEnum[adColFixed]
    //  NULLlǂ
    else
    if (AdoType = adColNullable) then
        Result := S_ColumnAttributesEnum[adColNullable]
    //  
    else
    if (AdoType = adColFixed + adColNullable) then
        Result := S_ColumnAttributesEnum[adColFixed] + '/' + S_ColumnAttributesEnum[adColNullable]
    //  ǂłȂ
    else
        Result := '';
end;

//-----------------------------------------------------------------------------
//  CfbNX̑
function AllowNullsEnum2Str(const AdoType: integer): string;
var
    s: array[0..3] of string; 
begin
    FillChar(s, Length(s), #0);

    if FlagInclude(AdoType, adIndexNullsAllow) then
        s[0] := S_AllowNullsEnum[adIndexNullsAllow]
    else
    begin
        if FlagInclude(AdoType, adIndexNullsDisallow) then
            s[1] := S_AllowNullsEnum[adIndexNullsDisallow];
        if FlagInclude(AdoType, adIndexNullsIgnore) then
            s[2] := S_AllowNullsEnum[adIndexNullsIgnore];
        if FlagInclude(AdoType, adIndexNullsIgnoreAny) then
            s[3] := S_AllowNullsEnum[adIndexNullsIgnoreAny];
    end;

    Result := s[0];
    if (s[0] <> '') then Result := Result + 'E' + s[1] else Result := s[1]; 
    if (s[0] + s[1] <> '') then Result := Result + 'E' + s[2] else Result := s[2];
    if (s[0] + s[1] + s[2] <> '') then Result := Result + 'E' + s[3] else Result := s[3];
end;

//-----------------------------------------------------------------------------
//  vpeB̖|
var
    PROP_TABLE: TStringList;

function TransPropName(const PropName: string): string;
begin
    Result := PROP_TABLE.Values[PropName];
    if (Result = '') then Result := PropName;
end;

//-----------------------------------------------------------------------------
//  |e[u쐬
procedure MakeTransTable();
begin
    //  Tablep
    PROP_TABLE.Add('Temporary Table=ꎞ\');
    PROP_TABLE.Add('Jet OLEDB:Table Validation Text=͋KᔽbZ[W');
    PROP_TABLE.Add('Jet OLEDB:Table Validation Rule=͋K');
    PROP_TABLE.Add('Jet OLEDB:Cache Link Name/Password=ID/pX[hLbV');
    PROP_TABLE.Add('Jet OLEDB:Remote Table Name=[g\');
    PROP_TABLE.Add('Jet OLEDB:Link Provider String=Link Provider String');
    PROP_TABLE.Add('Jet OLEDB:Link Datasource=Link Datasource');
    PROP_TABLE.Add('Jet OLEDB:Exclusive Link=Exclusive Link');
    PROP_TABLE.Add('Jet OLEDB:Create Link=Create Link');
    PROP_TABLE.Add('Jet OLEDB:Table Hidden In Access=AccessŉB');

    //  Columnp
    PROP_TABLE.Add('Autoincrement=');
    PROP_TABLE.Add('Default=l');
    PROP_TABLE.Add('Description=');
    PROP_TABLE.Add('Nullable=NULL');
    PROP_TABLE.Add('Fixed Length=Œ蒷');
    PROP_TABLE.Add('Seed=Seed');
    PROP_TABLE.Add('Increment=Increment');
    PROP_TABLE.Add('Jet OLEDB:Column Validation Text=K');
    PROP_TABLE.Add('Jet OLEDB:Column Validation Rule=͋K');
    PROP_TABLE.Add('Jet OLEDB:IISAM Not Last Column=IISAM Not Last Column');
    PROP_TABLE.Add('Jet OLEDB:AutoGenerate=');
    PROP_TABLE.Add('Jet OLEDB:One BLOB per Page=One BLOB per Page');
    PROP_TABLE.Add('Jet OLEDB:Compressed UNICODE Strings=Unicodek');
    PROP_TABLE.Add('Jet OLEDB:Allow Zero Length=󕶎');
    PROP_TABLE.Add('Jet OLEDB:Hyperlink=Hyperlink');

    //  ڑIuWFNgp
    PROP_TABLE.Add('Current Catalog=݂Catalog');
    PROP_TABLE.Add('Active Sessions=ANeBuȃZbV');
    PROP_TABLE.Add('Asynchable Commit=Asynchable Commit');
    PROP_TABLE.Add('Catalog Location=Catalog Location');
    PROP_TABLE.Add('Catalog Term=Catalog Term');
    PROP_TABLE.Add('Column Definition=Column Definition');
    PROP_TABLE.Add('NULL Concatenation Behavior=NULL Concatenation Behavior');
    PROP_TABLE.Add('Data Source Name=f[^\[X');
    PROP_TABLE.Add('Read-Only Data Source=ǎpf[^\[X');
    PROP_TABLE.Add('DBMS Name=DBMS');
    PROP_TABLE.Add('DBMS Version=DBMS̃o[W');
    PROP_TABLE.Add('GROUP BY Support=GROUP BYT|[g');
    PROP_TABLE.Add('Heterogeneous Table Support=Heterogeneous Table Support');
    PROP_TABLE.Add('Identifier Case Sensitivity=Identifier Case Sensitivity');
    PROP_TABLE.Add('Maximum Index Size=őCfbNXTCY');
    PROP_TABLE.Add('Maximum Row Size=ős');
    PROP_TABLE.Add('Maximum Row Size Includes BLOB=BLOB܂ލős');
    PROP_TABLE.Add('Maximum Tables in SELECT=SELECT\ȍő\');
    PROP_TABLE.Add('Multiple Storage Objects=Multiple Storage Objects');
    PROP_TABLE.Add('Multi-Table Update=e[uXV');
    PROP_TABLE.Add('NULL Collation Order=NULL Collation Order');
    PROP_TABLE.Add('OLE Object Support=OLE ObjectT|[g');
    PROP_TABLE.Add('ORDER BY Columns in Select List=IXgŗ\[g');
    PROP_TABLE.Add('Prepare Abort Behavior=Prepare Abort Behavior');
    PROP_TABLE.Add('Prepare Commit Behavior=Prepare Commit Behavior');
    PROP_TABLE.Add('Procedure Term=Procedure Term');
    PROP_TABLE.Add('Provider Name=voC_');
    PROP_TABLE.Add('OLE DB Version=OLE DB̃o[W');
    PROP_TABLE.Add('Provider Version=voC_̃o[W');
    PROP_TABLE.Add('Schema Term=Schema Term');
    PROP_TABLE.Add('Schema Usage=Schema Usage');
    PROP_TABLE.Add('SQL Support=SQLT|[g');
    PROP_TABLE.Add('Structured Storage=\Xg[W');
    PROP_TABLE.Add('Subquery Support=TuNGT|[g');
    PROP_TABLE.Add('Isolation Levels=Isolation Levels');
    PROP_TABLE.Add('Isolation Retention=Isolation Retention');
    PROP_TABLE.Add('Table Term=Table Term');
    PROP_TABLE.Add('User Name=[U[');
    PROP_TABLE.Add('Pass By Ref Accessors=Pass By Ref Accessors');
    PROP_TABLE.Add('Transaction DDL=Transaction DDL');
    PROP_TABLE.Add('Asynchable Abort=Asynchable Abort');
    PROP_TABLE.Add('Data Source Object Threading Model=Data Source Object Threading Model');
    PROP_TABLE.Add('Output Parameter Availability=Output Parameter Availability');
    PROP_TABLE.Add('Persistent ID Type=Persistent ID Type');
    PROP_TABLE.Add('Multiple Parameter Sets=Multiple Parameter Sets');
    PROP_TABLE.Add('Rowset Conversions on Command=Rowset Conversions on Command');
    PROP_TABLE.Add('Multiple Results=Multiple Results');
    PROP_TABLE.Add('Provider Friendly Name=voC_');
    PROP_TABLE.Add('Alter Column Support=CT|[g');
    PROP_TABLE.Add('Open Rowset Support=Open Rowset Support');
    PROP_TABLE.Add('Cache Authentication=Cache Authentication');
    PROP_TABLE.Add('Encrypt Password=Encrypt Password');
    PROP_TABLE.Add('Mask Password=pX[h}XN');
    PROP_TABLE.Add('Password=pX[h');
    PROP_TABLE.Add('User ID=[U[ID');
    PROP_TABLE.Add('Data Source=f[^\[X');
    PROP_TABLE.Add('Window Handle=EBhEnh');
    PROP_TABLE.Add('Mode=[h');
    PROP_TABLE.Add('Prompt=vvg');
    PROP_TABLE.Add('Extended Properties=gvpeB');
    PROP_TABLE.Add('Locale Identifier=P[ID');
    PROP_TABLE.Add('Jet OLEDB:System database=VXef[^x[X');
    PROP_TABLE.Add('Jet OLEDB:Registry Path=WXgpX');
    PROP_TABLE.Add('Jet OLEDB:Database Password=f[^x[XpX[h');
    PROP_TABLE.Add('Jet OLEDB:Engine Type=Engine Type');
    PROP_TABLE.Add('Jet OLEDB:Database Locking Mode=f[^x[XbN[h');
    PROP_TABLE.Add('Jet OLEDB:Global Partial Bulk Ops=Global Partial Bulk Ops');
    PROP_TABLE.Add('Jet OLEDB:Global Bulk Transactions=Global Bulk Transactions');
    PROP_TABLE.Add('Jet OLEDB:New Database Password=Vf[^x[XpX[h');
    PROP_TABLE.Add('Jet OLEDB:Create System Database=VXef[^x[X쐬');
    PROP_TABLE.Add('Jet OLEDB:Encrypt Database=Encrypt Database');
    PROP_TABLE.Add('Jet OLEDB:Don''t Copy Locale on Compact=kP[𕡐Ȃ');
    PROP_TABLE.Add('Jet OLEDB:Compact Without Replica Repair=Compact Without Replica Repair=');
    PROP_TABLE.Add('Jet OLEDB:SFP=SFP');
    PROP_TABLE.Add('Jet OLEDB:Compact Reclaimed Space Amount=Compact Reclaimed Space Amount');
    PROP_TABLE.Add('Autocommit Isolation Levels=Autocommit Isolation Levels');
    PROP_TABLE.Add('Jet OLEDB:ODBC Command Time Out=ODBC Command Time Out');
    PROP_TABLE.Add('Jet OLEDB:Max Locks Per File=Max Locks Per File');
    PROP_TABLE.Add('Jet OLEDB:Implicit Commit Sync=Implicit Commit Sync');
    PROP_TABLE.Add('Jet OLEDB:Flush Transaction Timeout=Flush Transaction Timeout');
    PROP_TABLE.Add('Jet OLEDB:Lock Delay=Lock Delay');
    PROP_TABLE.Add('Jet OLEDB:Max Buffer Size=őobt@TCY');
    PROP_TABLE.Add('Jet OLEDB:User Commit Sync=User Commit Sync');
    PROP_TABLE.Add('Jet OLEDB:Lock Retry=Lock Retry');
    PROP_TABLE.Add('Jet OLEDB:Exclusive Async Delay=Exclusive Async Delay');
    PROP_TABLE.Add('Jet OLEDB:Shared Async Delay=Shared Async Delay');
    PROP_TABLE.Add('Jet OLEDB:Page Timeout=y[W^CAEg');
    PROP_TABLE.Add('Jet OLEDB:Recycle Long-Valued Pages=Recycle Long-Valued Pages');
    PROP_TABLE.Add('Jet OLEDB:Reset ISAM Stats=Reset ISAM Stats');
    PROP_TABLE.Add('Jet OLEDB:Connection Control=ڑ');
    PROP_TABLE.Add('Jet OLEDB:ODBC Parsing=ODBC Parsing');
    PROP_TABLE.Add('Jet OLEDB:Page Locks to Table Lock=Page Locks to Table Lock');
    PROP_TABLE.Add('Jet OLEDB:Sandbox Mode=Sandbox Mode');
    PROP_TABLE.Add('Jet OLEDB:Transaction Commit Mode=Transaction Commit Mode');
end;

initialization
    PROP_TABLE := TStringList.Create;
    MakeTransTable();
finalization
    PROP_TABLE.Free;
end.

